@@ -5,11 +5,12 @@ from sklearn.metrics import confusion_matrix
 def class_balance_accuracy_score(y_true, y_pred):
     """
     Function for Class Balance Accuracy scorer
-    (p. 40 in `Mosley 2013 <https://lib.dr.iastate.edu/cgi/viewcontent.cgi?article=4544&context=etd>`_).
+    (p. 40 in [Mosley 2013](https://lib.dr.iastate.edu/cgi/viewcontent.cgi?article=4544&context=etd)).
 
     :param array y_true: True classes, shape = [n_samples].
     :param array y_pred: Predicted classes, shape = [n_samples].
-    :return: cba (`float`): The Class Balance Accuracy score.
+    :return: The Class Balance Accuracy score.
+    :rtype: float
     """
 
     cm = confusion_matrix(y_true, y_pred)
