@@ -1,7 +1,11 @@
 from nltk import word_tokenize
 from nltk.stem import WordNetLemmatizer
 import spacy
-nlp = spacy.load("en_core_web_sm") # Don't put this inside the function- loading it in every CV iteration would tremendously slow down the pipeline.
+
+try:
+    nlp = spacy.load("en_core_web_sm") # Don't put this inside the function- loading it in every CV iteration would tremendously slow down the pipeline.
+except OSError:
+    print('Warning! Have you downloaded the spacy models? Run " python -m spacy download en_core_web_sm " in your terminal')
 
 
 class LemmaTokenizer:
